..
    .. include:: ../README.rst

User guide
----------

.. toctree::
   :maxdepth: 2

   user/install
..    user/citation


API
----------

.. toctree::
   :maxdepth: 2

   api/api
    

License & attribution
---------------------

Copyright 2019 Daniel Hey, Timothy Bedding

The source code is made available under the terms of the MIT license.


Changelog
---------

.. include:: ../CHANGES.rst